import logging
from typing import Optional, Union

import azure.cosmos.exceptions as exceptions
from fastapi import APIRouter
from pydantic import BaseModel

from app.endpoints.utils import check_if_quarterly_report, use_new_carbon_factors

from ..database.mycosmosdb import callConnect


class CMets(BaseModel):
    oid: str
    email: str
class CarbonMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: float
    s7: str
    s8: str
    s9: str
    s10: Optional[str]
class CarbonMeasureMAN(BaseModel):
    oid: str
    email: str
    metric: str
    label: str
    s1: Union[float, str] 
    s2: Union[float, str]
    s3: Union[float, str]
    s4: Union[float, str]
    s5: Union[float, str]
    s6: Union[float, str]
    s7: str
    s8: str
    s9: Union[float, str]
    s10: Union[float, str]
    s11: Union[float, str]
    s12: Union[float, str]
    s13: Union[float, str]
    s14: Union[float, str]
    s15: Union[float, str]

class CarbonMeasureEdit2(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: float
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: Optional[str]
    s14: Optional[str]
class CarbonMeasureEdit3(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: float
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: str
class CarbonMeasureCV(BaseModel):
    oid: str
    email: str
    metric: str
    part: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: float
    s6: float
    s7: str
    s8: str
    s9: Optional[str]
class CarbonMeasureEdit(BaseModel):
    oid: str
    email: str
    metric: str
    part: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: float
    s10: float
    s11: str
    s12: str
    s13: Optional[str]
    s14: Optional[str]
class CarbonMeasureSE(BaseModel):
    oid: str
    email: str
    metric: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: float
    s6: float
    s7: str
    s8: str
class CarbonMeasureSEEdit(BaseModel):
    oid: str
    email: str
    metric: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: float
    s10: float
    s11: str
    s12: str

class CompanyManufactured(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    m6: bool
    m7: bool
    m8: bool
    m9: bool
    m10: bool
    m11: bool
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: str

class CarbonMeasureSEDEL(BaseModel):
    oid: str
    email: str
    metric: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: float
    s10: float
    s11: str
    s12: str
class NewOffset(BaseModel):
    oid: str
    email: str
    year: str
    quarter: str
    credits: int
    metric: str
class ReduceEmissions(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    m6: bool
    m7: bool
    m8: bool
    s1: str
    s2: str
    s3: str





def read_item(container, doc_id, account_number):
    # We can do an efficient point read lookup on partition key and id
    response = container.read_item(item=doc_id, partition_key=account_number)
    return response


carbonroute = APIRouter()



"""
Endpoint used to grab all of the carbon measure pages in the DB
"""
@carbonroute.post('/getcarbonmeasure')
async def get_carbon_measure(cmet: CMets):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /getcarbonmeasure')
        return {"url": "/", "atype": False}
    

    if "carbonmeasure" in db_result:
        return {"cmets": db_result["carbonmeasure"]}


"""
Endpoint used to update the target metrics.
"""
@carbonroute.post('/carbonmeasure')
async def carbon_measure(cmet: CarbonMeasure):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasure')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CarbonInit":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonInit"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CarbonInit"]):
                carbonData = [z for z in db_result["carbonmeasure"] if z["label"] == "CarbonInit"][0]

                if ([a for a in carbonData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in carbonData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = [{
                        "mobileVehicles": cmet.m1,
                        "combustionEngine": cmet.m2,
                        "chemmatManufacturing": cmet.m3,
                        "refrigeration": cmet.m4,
                        "noneofabove": cmet.m5
                    }]
                    tmeas = [a for a in carbonData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CarbonInit",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "mobileVehicles": cmet.m1,
                        "combustionEngine": cmet.m2,
                        "chemmatManufacturing": cmet.m3,
                        "refrigeration": cmet.m4,
                        "noneofabove": cmet.m5
                    }]
                    tmeas = [a for a in carbonData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CarbonInit",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonInit"]
                newMet = {
                    "label": "CarbonInit",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": [
                                            {
                                                "mobileVehicles": cmet.m1,
                                                "combustionEngine": cmet.m2,
                                                "chemmatManufacturing": cmet.m3,
                                                "refrigeration": cmet.m4,
                                                "noneofabove": cmet.m5
                                            }
                                        ]
                                    }
                                ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "CStart":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CStart"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CStart"]):
                carbonData = [z for z in db_result["carbonmeasure"] if z["label"] == "CStart"][0]

                if ([a for a in carbonData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in carbonData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = [{
                        "cstart": cmet.m1,
                        "csurvey": cmet.m2
                    }]
                    tmeas = [a for a in carbonData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CStart",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "cstart": cmet.m1,
                        "csurvey": cmet.m2
                    }]
                    tmeas = [a for a in carbonData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CStart",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CStart"]
                newMet = {
                    "label": "CStart",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": [
                                            {
                                                "cstart": cmet.m1,
                                                "csurvey": cmet.m2
                                            }
                                        ]
                                    }
                                ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "RemoteWorkers":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RemoteWorkers"]
            tenID = ""
            cfactor = ""
            tenID = "CountryCodes_2023" if use_new_carbon_factors(cmet.s7, cmet.s8) else "CountryCodes_2022"
            fulls = 1
            parts = 1
            
            quarterly_report = check_if_quarterly_report(cmet.s8)
            divisor = 4 if quarterly_report else 1

            try:
                cfactor = read_item(callConnect.container10, tenID, cmet.s3)
                fulls = float(cfactor["Annual Emissions for Full-Time Employee"]) * float(cmet.s1)
                parts = float(cfactor["Annual Emissions for Part-Time Employee"]) * float(cmet.s2)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /carbonmeasure')
                return {"url": "/", "atype": False}

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkers"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkers"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "remoteWorkers80": cmet.m1,
                        "remoteWorkersFull": cmet.s1,
                        "remoteWorkersPart": cmet.s2,
                        "country": cmet.s3,
                        "carbonEmissions": (fulls + parts) / divisor
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "RemoteWorkers",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "remoteWorkers80": cmet.m1,
                        "remoteWorkersFull": cmet.s1,
                        "remoteWorkersPart": cmet.s2,
                        "country": cmet.s3,
                        "carbonEmissions": (fulls + parts) / divisor
                        
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "RemoteWorkers",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RemoteWorkers"]
                newMet = {
                    "label": "RemoteWorkers",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                    "remoteWorkers80": cmet.m1,
                                                    "remoteWorkersFull": cmet.s1,
                                                    "remoteWorkersPart": cmet.s2,
                                                    "country": cmet.s3,
                                                    "carbonEmissions": (fulls + parts) / divisor
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)       
        elif cmet.metric == "RemoteWorkersBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RemoteWorkersBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkersBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkersBool"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "RemoteWorkersBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "RemoteWorkersBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RemoteWorkersBool"]
                newMet = {
                    "label": "RemoteWorkersBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Electricity":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }     
            
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Electricity"]
            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"]):
                elecData = [z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"][0]
                if ([a for a in elecData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in elecData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        qrt = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        if ([z for z in qrt["metrics"] if z["label"] == "1"]):
                            nmetlis = [z for z in qrt["metrics"] if z["label"] == "1"]
                            cmeas = nmetlis[0]["value"]

                            nmetlis2 = [z for z in qrt["metrics"] if z["label"] == "2"]
                            cmeas2 = nmetlis2[0]["value"]

                            nmetlis3 = [z for z in qrt["metrics"] if z["label"] == "3"]
                            cmeas3 = nmetlis3[0]["value"]
                            if cmet.label == "elecCons":
                                tenID = ""
                                cfactor = ""
                                mul = 1
                                if cmet.s4 == "United States":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "ZipsST_2023"
                                    else:
                                        tenID = "ZipsST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                else:
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CountryCodes_2023"
                                    else:
                                        tenID = "CountryCodes_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                        mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}

                                cmeas.append({
                                        "amount": cmet.s1,
                                        "unitMeasure": cmet.s2,
                                        "timePeriod": cmet.s3,
                                        "country": cmet.s4,
                                        "zipCode": cmet.s5,
                                        "carbonEmissions": cmet.s6 * mul
                                    }
                                )
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s7]
                                quarterData.append({
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s7,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
                            elif cmet.label == "elecSpend":
                                tenID = ""
                                cfactor = ""
                                mul = 1
                                CE = 0
                                if cmet.s4 == "United States":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "ZipsST_2023"
                                    else:
                                        tenID = "ZipsST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                        kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                        CE = mul * kwH * .001
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                        kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                        CE = mul * kwH * .001
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                else:
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CountryCodes_2023"
                                    else:
                                        tenID = "CountryCodes_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                        kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                        mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                        CE = mul * kwH * .001
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}

                                cmeas2.append({
                                                "amountCurrency": cmet.s1,
                                                "timePeriod": cmet.s3,
                                                "country": cmet.s4,
                                                "zipCode": cmet.s5,
                                                "carbonEmissions": CE
                                            }
                                            )
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s7]
                                quarterData.append({
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s7,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
                            else:
                                tenID = ""
                                cfactor = ""
                                mul = 1
                                if cmet.s4 == "United States":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "ZipsST_2023"
                                    else:
                                        tenID = "ZipsST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                else:
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CountryCodes_2023"
                                    else:
                                        tenID = "CountryCodes_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                        mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                
                                if cmet.label == "Size":
                                    cmeas3.append({
                                        "squareFeet": cmet.s1,
                                        "unitMeasure": cmet.s10,
                                        "siteType": cmet.s2,
                                        "country": cmet.s4,
                                        "zipCode": cmet.s5,
                                        "carbonEmissions": cmet.s6 * mul
                                        }
                                    )
                                else:
                                    cmeas3.append({
                                        "squareFeet": cmet.s1,
                                        "siteType": cmet.s2,
                                        "country": cmet.s4,
                                        "zipCode": cmet.s5,
                                        "carbonEmissions": cmet.s6 * mul
                                        }
                                    )
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s7]
                                quarterData.append({
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s7,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
                    
                    
                    else:
                        if cmet.label == "elecCons":
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s7, cmet.s8):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            newMet = {
                            "label": "Electricity",
                            "metrics": [
                                {
                                    "label": cmet.s7,
                                    "value": [
                                        {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "0",
                                                "value": [
                                                    {
                                                        "electricity": cmet.m1,
                                                        "renewable": cmet.s9,
                                                        "amtElectricity": cmet.m2,
                                                        "spendElectricity": cmet.m3,
                                                        "sqftSites": cmet.m4
                                                    }
                                                ]
                                            },
                                            {
                                                "label": "1",
                                                "value": [
                                                    {
                                                        "amount": cmet.s1,
                                                        "unitMeasure": cmet.s2,
                                                        "timePeriod": cmet.s3,
                                                        "country": cmet.s4,
                                                        "zipCode": cmet.s5,
                                                        "carbonEmissions": cmet.s6 * mul
                                                    }
                                                ]
                                            },
                                            {
                                                "label": "2",
                                                "value": []
                                            },
                                            {
                                                "label": "3",
                                                "value": []
                                            }
                                                
                                        ]
                                        }
                                    ]
                                }
                            ]
                            }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)
                        elif cmet.label == "elecSpend":
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            CE = 0
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    CE = mul * kwH * .001
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "CanadaST_2023"
                                else:
                                    tenID = "CanadaST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    CE = mul * kwH * .001
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                    CE = mul * kwH * .001
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            newMet = {
                            "label": "Electricity",
                            "metrics": [
                                {
                                    "label": cmet.s7,
                                    "value": [
                                        {
                                            "label": cmet.s8,
                                            "metrics": [
                                                {
                                                    "label": "0",
                                                    "value": [
                                                        {
                                                            "electricity": cmet.m1,
                                                            "renewable": cmet.s9,
                                                            "amtElectricity": cmet.m2,
                                                            "spendElectricity": cmet.m3,
                                                            "sqftSites": cmet.m4
                                                        }
                                                    ]
                                                },
                                                {
                                                    "label": "1",
                                                    "value": []
                                                },
                                                {
                                                    "label": "2",
                                                    "value": [
                                                        {
                                                            "amountCurrency": cmet.s1,
                                                            "timePeriod": cmet.s3,
                                                            "country": cmet.s4,
                                                            "zipCode": cmet.s5,
                                                            "carbonEmissions": CE
                                                        }
                                                    ]
                                                },
                                                {
                                                    "label": "3",
                                                    "value": []
                                                }
                                            
                                            ]
                                        }
                                    ]
                                }
                            ]
                            }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)
                        else:
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "CanadaST_2023"
                                else:
                                    tenID = "CanadaST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s7, cmet.s8):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            newMet = {}
                            if cmet.label == "Size":
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": [
                                        {
                                            "label": cmet.s7,
                                            "value": [
                                                {
                                                    "label": cmet.s8,
                                                    "metrics": [
                                                        {
                                                            "label": "0",
                                                            "value": [
                                                                {
                                                                    "electricity": cmet.m1,
                                                                    "renewable": cmet.s9,
                                                                    "amtElectricity": cmet.m2,
                                                                    "spendElectricity": cmet.m3,
                                                                    "sqftSites": cmet.m4
                                                                }
                                                            ]
                                                        },
                                                        {
                                                            "label": "1",
                                                            "value": []
                                                        },
                                                        {
                                                            "label": "2",
                                                            "value": []
                                                        },
                                                        {
                                                            "label": "3",
                                                            "value": [
                                                                {
                                                                    "squareFeet": cmet.s1,
                                                                    "unitMeasure": cmet.s10,
                                                                    "siteType": cmet.s2,
                                                                    "country": cmet.s4,
                                                                    "zipCode": cmet.s5,
                                                                    "carbonEmissions": cmet.s6 * mul
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            else:
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": [
                                        {
                                            "label": cmet.s7,
                                            "value": [
                                                {
                                                    "label": cmet.s8,
                                                    "metrics": [
                                                        {
                                                            "label": "0",
                                                            "value": [
                                                                {
                                                                    "electricity": cmet.m1,
                                                                    "renewable": cmet.s9,
                                                                    "amtElectricity": cmet.m2,
                                                                    "spendElectricity": cmet.m3,
                                                                    "sqftSites": cmet.m4
                                                                }
                                                            ]
                                                        },
                                                        {
                                                            "label": "1",
                                                            "value": []
                                                        },
                                                        {
                                                            "label": "2",
                                                            "value": []
                                                        },
                                                        {
                                                            "label": "3",
                                                            "value": [
                                                                {
                                                                    "squareFeet": cmet.s1,
                                                                    "siteType": cmet.s2,
                                                                    "country": cmet.s4,
                                                                    "zipCode": cmet.s5,
                                                                    "carbonEmissions": cmet.s6 * mul
                                                                }
                                                            ]
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)

                else:
                    if cmet.label == "elecCons":
                        tenID = ""
                        cfactor = ""
                        mul = 1
                        if cmet.s4 == "United States":
                            if  use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "ZipsST_2023"
                            else:
                                tenID = "ZipsST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        elif cmet.s4 == "Canada":
                            if  use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "CanadaST_2023"
                            else:
                                tenID = "CanadaST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        else:
                            if  use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "CountryCodes_2023"
                            else:
                                tenID = "CountryCodes_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                # float(x)
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        newMet = {
                        "label": "Electricity",
                        "metrics": [
                            {
                                "label": cmet.s7,
                                "value": [
                                    {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": [
                                                {
                                                    "amount": cmet.s1,
                                                    "unitMeasure": cmet.s2,
                                                    "timePeriod": cmet.s3,
                                                    "country": cmet.s4,
                                                    "zipCode": cmet.s5,
                                                    "carbonEmissions": cmet.s6 * mul
                                                }
                                            ]
                                        },
                                        {
                                            "label": "2",
                                            "value": []
                                        },
                                        {
                                            "label": "3",
                                            "value": []
                                        }
                                            
                                    ]
                                    }
                                ]
                            }
                        ]
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    elif cmet.label == "elecSpend":
                        tenID = ""
                        cfactor = ""
                        mul = 1
                        CE = 0
                        if cmet.s4 == "United States":
                            if use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "ZipsST_2023"
                            else:
                                tenID = "ZipsST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                CE = mul * kwH * .001
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        elif cmet.s4 == "Canada":
                            if  use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "CanadaST_2023"
                            else:
                                tenID = "CanadaST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                CE = mul * kwH * .001
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        else:
                            if  use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "CountryCodes_2023"
                            else:
                                tenID = "CountryCodes_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                CE = mul * kwH * .001
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        newMet = {
                        "label": "Electricity",
                        "metrics": [
                            {
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "0",
                                                "value": [
                                                    {
                                                        "electricity": cmet.m1,
                                                        "renewable": cmet.s9,
                                                        "amtElectricity": cmet.m2,
                                                        "spendElectricity": cmet.m3,
                                                        "sqftSites": cmet.m4
                                                    }
                                                ]
                                            },
                                            {
                                                "label": "1",
                                                "value": []
                                            },
                                            {
                                                "label": "2",
                                                "value": [
                                                    {
                                                        "amountCurrency": cmet.s1,
                                                        "timePeriod": cmet.s3,
                                                        "country": cmet.s4,
                                                        "zipCode": cmet.s5,
                                                        "carbonEmissions": CE
                                                    }
                                                ]
                                            },
                                            {
                                                "label": "3",
                                                "value": []
                                            }
                                        
                                        ]
                                    }
                                ]
                            }
                        ]
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        tenID = ""
                        cfactor = ""
                        mul = 1
                        if cmet.s4 == "United States":
                            if use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "ZipsST_2023"
                            else:
                                tenID = "ZipsST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        elif cmet.s4 == "Canada":
                            if use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "CanadaST_2023"
                            else:
                                tenID = "CanadaST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        else:
                            if use_new_carbon_factors(cmet.s7, cmet.s8):
                                tenID = "CountryCodes_2023"
                            else:
                                tenID = "CountryCodes_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        newMet = {
                        "label": "Electricity",
                        "metrics": [
                            {
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "0",
                                                "value": [
                                                    {
                                                        "electricity": cmet.m1,
                                                        "renewable": cmet.s9,
                                                        "amtElectricity": cmet.m2,
                                                        "spendElectricity": cmet.m3,
                                                        "sqftSites": cmet.m4
                                                    }
                                                ]
                                            },
                                            {
                                                "label": "1",
                                                "value": []
                                            },
                                            {
                                                "label": "2",
                                                "value": []
                                            },
                                            {
                                                "label": "3",
                                                "value": [
                                                    {
                                                        "squareFeet": cmet.s1,
                                                        "siteType": cmet.s2,
                                                        "country": cmet.s4,
                                                        "zipCode": cmet.s5,
                                                        "carbonEmissions": cmet.s6 * mul
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                        }
                        newMet = {}
                        if cmet.label == "Size":
                            newMet = {
                                "label": "Electricity",
                                "metrics": [
                                    {
                                        "label": cmet.s7,
                                        "value": [
                                            {
                                                "label": cmet.s8,
                                                "metrics": [
                                                    {
                                                        "label": "0",
                                                        "value": [
                                                            {
                                                                "electricity": cmet.m1,
                                                                "renewable": cmet.s9,
                                                                "amtElectricity": cmet.m2,
                                                                "spendElectricity": cmet.m3,
                                                                "sqftSites": cmet.m4
                                                            }
                                                        ]
                                                    },
                                                    {
                                                        "label": "1",
                                                        "value": []
                                                    },
                                                    {
                                                        "label": "2",
                                                        "value": []
                                                    },
                                                    {
                                                        "label": "3",
                                                        "value": [
                                                            {
                                                                "squareFeet": cmet.s1,
                                                                "unitMeasure": cmet.s10,
                                                                "siteType": cmet.s2,
                                                                "country": cmet.s4,
                                                                "zipCode": cmet.s5,
                                                                "carbonEmissions": cmet.s6 * mul
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        else:
                            newMet = {
                                "label": "Electricity",
                                "metrics": [
                                    {
                                        "label": cmet.s7,
                                        "value": [
                                            {
                                                "label": cmet.s8,
                                                "metrics": [
                                                    {
                                                        "label": "0",
                                                        "value": [
                                                            {
                                                                "electricity": cmet.m1,
                                                                "renewable": cmet.s9,
                                                                "amtElectricity": cmet.m2,
                                                                "spendElectricity": cmet.m3,
                                                                "sqftSites": cmet.m4
                                                            }
                                                        ]
                                                    },
                                                    {
                                                        "label": "1",
                                                        "value": []
                                                    },
                                                    {
                                                        "label": "2",
                                                        "value": []
                                                    },
                                                    {
                                                        "label": "3",
                                                        "value": [
                                                            {
                                                                "squareFeet": cmet.s1,
                                                                "siteType": cmet.s2,
                                                                "country": cmet.s4,
                                                                "zipCode": cmet.s5,
                                                                "carbonEmissions": cmet.s6 * mul
                                                            }
                                                        ]
                                                    }
                                                ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)

            
            else:
                if cmet.label == "elecCons":
                    tenID = ""
                    cfactor = ""
                    mul = 1
                    if cmet.s4 == "United States":
                        if  use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "ZipsST_2023"
                        else:
                            tenID = "ZipsST_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                            mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    elif cmet.s4 == "Canada":
                        if  use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "CanadaST_2023"
                        else:
                            tenID = "CanadaST_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                            mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    else:
                        if  use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "CountryCodes_2023"
                        else:
                            tenID = "CountryCodes_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                            mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                        except exceptions.CosmosHttpResponseError as e:
                            return {"url": "/", "atype": False}
                    newMet = {
                    "label": "Electricity",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "0",
                                        "value": [
                                            {
                                                "electricity": cmet.m1,
                                                "renewable": cmet.s9,
                                                "amtElectricity": cmet.m2,
                                                "spendElectricity": cmet.m3,
                                                "sqftSites": cmet.m4
                                            }
                                        ]
                                    },
                                    {
                                        "label": "1",
                                        "value": [
                                            {
                                                "amount": cmet.s1,
                                                "unitMeasure": cmet.s2,
                                                "timePeriod": cmet.s3,
                                                "country": cmet.s4,
                                                "zipCode": cmet.s5,
                                                "carbonEmissions": cmet.s6 * mul
                                            }
                                        ]
                                    },
                                    {
                                        "label": "2",
                                        "value": []
                                    },
                                    {
                                        "label": "3",
                                        "value": []
                                    }
                                        
                                ]
                                }
                            ]
                        }
                    ]
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                elif cmet.label == "elecSpend":
                    tenID = ""
                    cfactor = ""
                    mul = 1
                    CE = 0
                    if cmet.s4 == "United States":
                        if use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "ZipsST_2023"
                        else:
                            tenID = "ZipsST_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                            kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                            mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            CE = mul * kwH * .001
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    elif cmet.s4 == "Canada":
                        if use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "CanadaST_2023"
                        else:
                            tenID = "CanadaST_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                            kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                            mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            CE = mul * kwH * .001
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    else:
                        if use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "CountryCodes_2023"
                        else:
                            tenID = "CountryCodes_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                            kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                            mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                            CE = mul * kwH * .001
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    newMet = {
                    "label": "Electricity",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": []
                                        },
                                        {
                                            "label": "2",
                                            "value": [
                                                {
                                                    "amountCurrency": cmet.s1,
                                                    "timePeriod": cmet.s3,
                                                    "country": cmet.s4,
                                                    "zipCode": cmet.s5,
                                                    "carbonEmissions": CE
                                                }
                                            ]
                                        },
                                        {
                                            "label": "3",
                                            "value": []
                                        }
                                    
                                    ]
                                }
                            ]
                        }
                    ]
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    tenID = ""
                    cfactor = ""
                    mul = 1
                    if cmet.s4 == "United States":
                        if use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "ZipsST_2023"
                        else:
                            tenID = "ZipsST_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                            mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    elif cmet.s4 == "Canada":
                        if use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "CanadaST_2023"
                        else:
                            tenID = "CanadaST_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                            mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    else:
                        if use_new_carbon_factors(cmet.s7, cmet.s8):
                            tenID = "CountryCodes_2023"
                        else:
                            tenID = "CountryCodes_2022"

                        try:
                            cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                            mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                        except exceptions.CosmosHttpResponseError as e:
                            logging.error('This is an error message for /carbonmeasure container10')
                            return {"url": "/", "atype": False}
                    
                    newMet = {}
                    if cmet.label == "Size":
                        newMet = {
                            "label": "Electricity",
                            "metrics": [
                                {
                                    "label": cmet.s7,
                                    "value": [
                                        {
                                            "label": cmet.s8,
                                            "metrics": [
                                                {
                                                    "label": "0",
                                                    "value": [
                                                        {
                                                            "electricity": cmet.m1,
                                                            "renewable": cmet.s9,
                                                            "amtElectricity": cmet.m2,
                                                            "spendElectricity": cmet.m3,
                                                            "sqftSites": cmet.m4
                                                        }
                                                    ]
                                                },
                                                {
                                                    "label": "1",
                                                    "value": []
                                                },
                                                {
                                                    "label": "2",
                                                    "value": []
                                                },
                                                {
                                                    "label": "3",
                                                    "value": [
                                                        {
                                                            "squareFeet": cmet.s1,
                                                            "unitMeasure": cmet.s10,
                                                            "siteType": cmet.s2,
                                                            "country": cmet.s4,
                                                            "zipCode": cmet.s5,
                                                            "carbonEmissions": cmet.s6 * mul
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    else:
                        newMet = {
                            "label": "Electricity",
                            "metrics": [
                                {
                                    "label": cmet.s7,
                                    "value": [
                                        {
                                            "label": cmet.s8,
                                            "metrics": [
                                                {
                                                    "label": "0",
                                                    "value": [
                                                        {
                                                            "electricity": cmet.m1,
                                                            "renewable": cmet.s9,
                                                            "amtElectricity": cmet.m2,
                                                            "spendElectricity": cmet.m3,
                                                            "sqftSites": cmet.m4
                                                        }
                                                    ]
                                                },
                                                {
                                                    "label": "1",
                                                    "value": []
                                                },
                                                {
                                                    "label": "2",
                                                    "value": []
                                                },
                                                {
                                                    "label": "3",
                                                    "value": [
                                                        {
                                                            "squareFeet": cmet.s1,
                                                            "siteType": cmet.s2,
                                                            "country": cmet.s4,
                                                            "zipCode": cmet.s5,
                                                            "carbonEmissions": cmet.s6 * mul
                                                        }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)  
        elif cmet.metric == "ElectricityBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "ElectricityBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "ElectricityBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "ElectricityBool"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "ElectricityBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "ElectricityBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "ElectricityBool"]
                newMet = {
                    "label": "ElectricityBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteam":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "HeatSteam"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteam"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteam"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "heat": cmet.m1,
                        "amount": cmet.s1,
                        "unitMeasure": cmet.s2,
                        "timePeriod": cmet.s3,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "HeatSteam",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "heat": cmet.m1,
                        "amount": cmet.s1,
                        "unitMeasure": cmet.s2,
                        "timePeriod": cmet.s3,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "HeatSteam",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "HeatSteam"]
                newMet = {
                    "label": "HeatSteam",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "heat": cmet.m1,
                                                        "amount": cmet.s1,
                                                        "unitMeasure": cmet.s2,
                                                        "timePeriod": cmet.s3,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteamSpend" or cmet.metric == "HeatSteamNG":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != cmet.metric]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == cmet.metric]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == cmet.metric][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "heat": cmet.m1,
                        "naturalGas": cmet.m2,
                        "spend": cmet.m3,
                        "amount": cmet.s1,
                        "unitMeasure": cmet.s2,
                        "timePeriod": cmet.s3,
                        "siteType": cmet.s4,
                        "country": cmet.s5,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": cmet.metric,
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "heat": cmet.m1,
                        "naturalGas": cmet.m2,
                        "spend": cmet.m3,
                        "amount": cmet.s1,
                        "unitMeasure": cmet.s2,
                        "timePeriod": cmet.s3,
                        "siteType": cmet.s4,
                        "country": cmet.s5,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": cmet.metric,
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != cmet.metric]
                newMet = {
                    "label": cmet.metric,
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "heat": cmet.m1,
                                                        "naturalGas": cmet.m2,
                                                        "spend": cmet.m3,
                                                        "amount": cmet.s1,
                                                        "unitMeasure": cmet.s2,
                                                        "timePeriod": cmet.s3,
                                                        "siteType": cmet.s4,
                                                        "country": cmet.s5,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteamBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "HeatSteamBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteamBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteamBool"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "HeatSteamBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "HeatSteamBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "HeatSteamBool"]
                newMet = {
                    "label": "HeatSteamBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "AirTravel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "AirTravel"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "AirTravel"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "AirTravel"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "air": cmet.m1,
                        "longHaul": cmet.s1,
                        "mediumHaul": cmet.s2,
                        "shortHaul": cmet.s3,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "AirTravel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "air": cmet.m1,
                        "longHaul": cmet.s1,
                        "mediumHaul": cmet.s2,
                        "shortHaul": cmet.s3,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "AirTravel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "AirTravel"]
                newMet = {
                    "label": "AirTravel",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "air": cmet.m1,
                                                        "longHaul": cmet.s1,
                                                        "mediumHaul": cmet.s2,
                                                        "shortHaul": cmet.s3,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "AirTravelBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "AirTravelBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "AirTravelBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "AirTravelBool"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "AirTravelBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "AirTravelBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "AirTravelBool"]
                newMet = {
                    "label": "AirTravelBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "RailTravel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RailTravel"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RailTravel"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "RailTravel"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "transportType": cmet.s1,
                        "distanceTraveled": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "RailTravel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "transportType": cmet.s1,
                        "distanceTraveled": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "RailTravel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RailTravel"]
                newMet = {
                    "label": "RailTravel",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "transportType": cmet.s1,
                                                        "distanceTraveled": cmet.s2,
                                                        "unitMeasure": cmet.s3,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Hotel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Hotel"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Hotel"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "Hotel"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "hotels": cmet.s1,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Hotel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "hotels": cmet.s1,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Hotel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Hotel"]
                newMet = {
                    "label": "Hotel",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "hotels": cmet.s1,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Commute":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Commute"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Commute"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "Commute"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "transportType": cmet.s1,
                        "distanceTraveled": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "numberEmployees": cmet.s4,
                        "daysWeek": cmet.s5,
                        "commute": cmet.m1,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Commute",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "transportType": cmet.s1,
                        "distanceTraveled": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "numberEmployees": cmet.s4,
                        "daysWeek": cmet.s5,
                        "commute": cmet.m1,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Commute",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Commute"]
                newMet = {
                    "label": "Commute",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "transportType": cmet.s1,
                                                        "distanceTraveled": cmet.s2,
                                                        "unitMeasure": cmet.s3,
                                                        "numberEmployees": cmet.s4,
                                                        "daysWeek": cmet.s5,
                                                        "commute": cmet.m1,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "CommuteBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CommuteBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CommuteBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "CommuteBool"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CommuteBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CommuteBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CommuteBool"]
                newMet = {
                    "label": "CommuteBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Cloud":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Cloud"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Cloud"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "Cloud"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "google": cmet.s1,
                        "aws": cmet.s2,
                        "azure": cmet.s3,
                        "oracle": cmet.s4,
                        "usage": cmet.s5,
                        "cloud": cmet.m1,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Cloud",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "google": cmet.s1,
                        "aws": cmet.s2,
                        "azure": cmet.s3,
                        "oracle": cmet.s4,
                        "usage": cmet.s5,
                        "cloud": cmet.m1,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Cloud",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Cloud"]
                newMet = {
                    "label": "Cloud",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "google": cmet.s1,
                                                        "aws": cmet.s2,
                                                        "azure": cmet.s3,
                                                        "oracle": cmet.s4,
                                                        "usage": cmet.s5,
                                                        "cloud": cmet.m1,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "CloudBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CloudBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CloudBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "CloudBool"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CloudBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CloudBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CloudBool"]
                newMet = {
                    "label": "CloudBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Emissions":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Emissions"]
            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Emissions"]):
                emData = [z for z in db_result["carbonmeasure"] if z["label"] == "Emissions"][0]

                if ([a for a in emData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in emData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = [
                        {
                            "scope1": cmet.s1,
                            "scope2": cmet.s2,
                            "scope3": cmet.s3
                        }
                    ]
                    tmeas = [a for a in emData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Emissions",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "scope1": cmet.s1,
                        "scope2": cmet.s2,
                        "scope3": cmet.s3
                    }]
                    tmeas = [a for a in emData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Emissions",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Emissions"]
                newMet = {
                    "label": "Emissions",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "scope1": cmet.s1,
                                                        "scope2": cmet.s2,
                                                        "scope3": cmet.s3
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "SPBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SPBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SPBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "SPBool"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas = [{
                        "ad": cmet.m1,
                        "sd": cmet.m2,
                        "btemissions": cmet.m3
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    newMet = {
                        "label": "SPBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "ad": cmet.m1,
                        "sd": cmet.m2,
                        "btemissions": cmet.m3
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "SPBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SPBool"]
                newMet = {
                    "label": "SPBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "ad": cmet.m1,
                                                        "sd": cmet.m2,
                                                        "btemissions": cmet.m3
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Spend":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Spend"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Spend"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "Spend"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "hotelSpend": cmet.s1,
                        "airTravel": cmet.s2,
                        "carTravel": cmet.s3,
                        "currency": cmet.s4,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Spend",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "hotelSpend": cmet.s1,
                        "airTravel": cmet.s2,
                        "carTravel": cmet.s3,
                        "currency": cmet.s4,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Spend",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Spend"]
                newMet = {
                    "label": "Spend",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "hotelSpend": cmet.s1,
                                                        "airTravel": cmet.s2,
                                                        "carTravel": cmet.s3,
                                                        "currency": cmet.s4,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "SpendAll":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SpendAll"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SpendAll"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "SpendAll"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "travelSpend": cmet.s1,
                        "currency": cmet.s2,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "SpendAll",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "travelSpend": cmet.s1,
                        "currency": cmet.s2,
                        "carbonEmissions": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "SpendAll",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SpendAll"]
                newMet = {
                    "label": "SpendAll",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "travelSpend": cmet.s1,
                                                        "currency": cmet.s2,
                                                        "carbonEmissions": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "ElectricityBool":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "ElectricityBool"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "ElectricityBool"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "ElectricityBool"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "boolean": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "ElectricityBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "boolean": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "ElectricityBool",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "ElectricityBool"]
                newMet = {
                    "label": "ElectricityBool",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "boolean": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)    
        elif cmet.metric == "CompanySite":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CompanySite"]

            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CompanySite"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "CompanySite"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "name": cmet.s1,
                        "type": cmet.s2,
                        "country": cmet.s3,
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CompanySite",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "name": cmet.s1,
                        "type": cmet.s2,
                        "country": cmet.s3,
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CompanySite",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CompanySite"]
                newMet = {
                    "label": "CompanySite",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "name": cmet.s1,
                                                        "type": cmet.s2,
                                                        "country": cmet.s3,
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Scope3GHG":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Scope3GHG"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Scope3GHG"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "Scope3GHG"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "operatingCost": cmet.s1,
                        "productCheckYes": cmet.m1,
                        "productCheckNo": cmet.m2,
                        "productDescription": cmet.s2,
                        "currency": cmet.s3,
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Scope3GHG",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "operatingCost": cmet.s1,
                        "productCheckYes": cmet.m1,
                        "productCheckNo": cmet.m2,
                        "productDescription": cmet.s2,
                        "currency": cmet.s3,
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Scope3GHG",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Scope3GHG"]
                newMet = {
                    "label": "Scope3GHG",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "operatingCost": cmet.s1,
                                                        "productCheckYes": cmet.m1,
                                                        "productCheckNo": cmet.m2,
                                                        "productDescription": cmet.s2,
                                                        "currency": cmet.s3,
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)    
        elif cmet.metric == "S3Ask":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "S3Ask"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "S3Ask"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "S3Ask"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = []
                    cmeas.append({
                        "s3": cmet.m1
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "S3Ask",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "s3": cmet.m1
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "S3Ask",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "S3Ask"]
                newMet = {
                    "label": "S3Ask",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "s3": cmet.m1
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)        

    


"""
Endppoint use to edit the Scope 2 Emissions
"""
@carbonroute.post('/carbonmeasureedit')
async def carbon_measure_edit(cmet: CarbonMeasureEdit2):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasureedit')
        return {"url": "/", "atype": False}

    if "carbonmeasure" in db_result:
        if cmet.metric == "CarbonInit":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonInit"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CarbonInit"]):
                carbonData = [z for z in db_result["carbonmeasure"] if z["label"] == "CarbonInit"][0]
                if ([a for a in carbonData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in carbonData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = [{
                        "mobileVehicles": cmet.m1,
                        "combustionEngine": cmet.m2,
                        "chemmatManufacturing": cmet.m3,
                        "refrigeration": cmet.m4,
                        "noneofabove": cmet.m5
                    }]
                    tmeas = [a for a in carbonData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CarbonInit",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "mobileVehicles": cmet.m1,
                        "combustionEngine": cmet.m2,
                        "chemmatManufacturing": cmet.m3,
                        "refrigeration": cmet.m4,
                        "noneofabove": cmet.m5
                    }]
                    tmeas = [a for a in carbonData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CarbonInit",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonInit"]
                newMet = {
                    "label": "CarbonInit",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": [
                                            {
                                                "mobileVehicles": cmet.m1,
                                                "combustionEngine": cmet.m2,
                                                "chemmatManufacturing": cmet.m3,
                                                "refrigeration": cmet.m4,
                                                "noneofabove": cmet.m5
                                            }
                                        ]
                                    }
                                    
                                ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "RemoteWorkers":
            user = {
            "id": db_result["id"],
            "email": db_result["email"],
            "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RemoteWorkers"]
            tenID = ""
            cfactor = ""
            tenID = "CountryCodes_2023" if use_new_carbon_factors(cmet.s10, cmet.s11) else "CountryCodes_2022"
            fulls = 1
            parts = 1

            quarterly_report = check_if_quarterly_report(cmet.s11)
            divisor = 4 if quarterly_report else 1
            
            try:
                cfactor = read_item(callConnect.container10, tenID, cmet.s3)
                fulls = float(cfactor["Annual Emissions for Full-Time Employee"]) * float(cmet.s1)
                parts = float(cfactor["Annual Emissions for Part-Time Employee"]) * float(cmet.s2)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /carbonmeasure container10')
                return {"url": "/", "atype": False}
            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkers"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkers"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["remoteWorkersFull"] != cmet.s7 or z["remoteWorkersPart"] != cmet.s8 or z["country"] != cmet.s9]
                        cmeasNEW.append({
                            "remoteWorkers80": cmet.m1,
                            "remoteWorkersFull": cmet.s1,
                            "remoteWorkersPart": cmet.s2,
                            "country": cmet.s3,
                            "carbonEmissions": (fulls + parts) / divisor
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "RemoteWorkers",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "remoteWorkers80": cmet.m1,
                            "remoteWorkersFull": cmet.s1,
                            "remoteWorkersPart": cmet.s2,
                            "country": cmet.s3,
                            "carbonEmissions": (fulls + parts) / divisor
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "RemoteWorkers",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "remoteWorkers80": cmet.m1,
                        "remoteWorkersFull": cmet.s1,
                        "remoteWorkersPart": cmet.s2,
                        "country": cmet.s3,
                        "carbonEmissions": (fulls + parts) / divisor
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "RemoteWorkers",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Electricity":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Electricity"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"]):
                elecData = [z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"][0]
                if ([a for a in elecData["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in elecData["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        qrt = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        if ([z for z in qrt["metrics"] if z["label"] == "1"]):
                            nmetlis = [z for z in qrt["metrics"] if z["label"] == "1"]
                            cmeas = nmetlis[0]["value"]
                            nmetlis2 = [z for z in qrt["metrics"] if z["label"] == "2"]
                            cmeas2 = nmetlis2[0]["value"]
                            nmetlis3 = [z for z in qrt["metrics"] if z["label"] == "3"]
                            cmeas3 = nmetlis3[0]["value"]
                            if cmet.label == "elecSpend":
                                tenID = ""
                                cfactor = ""
                                mul = 1
                                if cmet.s4 == "United States":
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "ZipsST_2023"
                                    else:
                                        tenID = "ZipsST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                        CE = mul * kwH * .001
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                        CE = mul * kwH * .001
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                else:
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "CountryCodes_2023"
                                    else:
                                        tenID = "CountryCodes_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                        kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                        mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                        CE = mul * kwH * .001
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                cmeas2NEW = [z for z in cmeas2 if z["amountCurrency"] != cmet.s7 or z["timePeriod"] != cmet.s8 or z["country"] != cmet.s9 or z["zipCode"] != cmet.s2]
                                cmeas2NEW.append({
                                    "amountCurrency": cmet.s1,
                                    "timePeriod": cmet.s3,
                                    "country": cmet.s4,
                                    "zipCode": cmet.s5,
                                    "carbonEmissions": CE
                                }
                                )
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                                quarterData.append({
                                    "label": cmet.s11,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s12,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2NEW
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s10,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
                            else:
                                tenID = ""
                                cfactor = ""
                                mul = 1
                                if cmet.s4 == "United States":
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "ZipsST_2023"
                                    else:
                                        tenID = "ZipsST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                else:
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "CountryCodes_2023"
                                    else:
                                        tenID = "CountryCodes_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                        mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                cmeas3NEW = []
                                if cmet.label == "Size":
                                    cmeas3NEW = [z for z in cmeas3 if z["squareFeet"] != cmet.s7 or z["siteType"] != cmet.s8 or z["country"] != cmet.s9 or z["zipCode"] != cmet.s3 or z["unitMeasure"] != cmet.s13]
                                    cmeas3NEW.append({
                                            "squareFeet": cmet.s1,
                                            "unitMeasure": cmet.s14,
                                            "siteType": cmet.s2,
                                            "country": cmet.s4,
                                            "zipCode": cmet.s5,
                                            "carbonEmissions": cmet.s6 * mul
                                        }
                                    )
                                else:
                                    cmeas3NEW = [z for z in cmeas3 if z["squareFeet"] != cmet.s7 or z["siteType"] != cmet.s8 or z["country"] != cmet.s9 or z["zipCode"] != cmet.s3]
                                    cmeas3NEW.append({
                                        "squareFeet": cmet.s1,
                                        "siteType": cmet.s2,
                                        "country": cmet.s4,
                                        "zipCode": cmet.s5,
                                        "carbonEmissions": cmet.s6 * mul
                                        }
                                    )
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                                quarterData.append({
                                    "label": cmet.s11,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s12,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3NEW
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s10,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
                    else:
                        qrt = []
                        cmeas = []
                        cmeas2 = []
                        cmeas3 = []
                        if cmet.label == "elecSpend":
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    CE = mul * kwH * .001
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CanadaST_2023"
                                else:
                                    tenID = "CanadaST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    CE = mul * kwH * .001
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                    CE = mul * kwH * .001
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            cmeas2NEW = []
                            cmeas2NEW.append({
                                "amountCurrency": cmet.s1,
                                "timePeriod": cmet.s3,
                                "country": cmet.s4,
                                "zipCode": cmet.s5,
                                "carbonEmissions": CE
                            }
                            )
                            tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                            quarterData.append({
                                "label": cmet.s11,
                                "metrics": [
                                    {
                                        "label": "0",
                                        "value": [
                                            {
                                                "electricity": cmet.m1,
                                                "renewable": cmet.s12,
                                                "amtElectricity": cmet.m2,
                                                "spendElectricity": cmet.m3,
                                                "sqftSites": cmet.m4
                                            }
                                        ]
                                    },
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    },
                                    {
                                        "label": "2",
                                        "value": cmeas2NEW
                                    },
                                    {
                                        "label": "3",
                                        "value": cmeas3
                                    }
                                ]
                            })
                            tmeas.append({
                                        "label": cmet.s10,
                                        "value": quarterData
                            })
                            newMet = {
                                "label": "Electricity",
                                "metrics": tmeas
                            }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)
                        else:
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CanadaST_2023"
                                else:
                                    tenID = "CanadaST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            cmeas3NEW = []
                            if cmet.label == "Size":
                                cmeas3NEW = []
                                cmeas3NEW.append({
                                        "squareFeet": cmet.s1,
                                        "unitMeasure": cmet.s14,
                                        "siteType": cmet.s2,
                                        "country": cmet.s4,
                                        "zipCode": cmet.s5,
                                        "carbonEmissions": cmet.s6 * mul
                                    }
                                )
                            else:
                                cmeas3NEW = []
                                cmeas3NEW.append({
                                    "squareFeet": cmet.s1,
                                    "siteType": cmet.s2,
                                    "country": cmet.s4,
                                    "zipCode": cmet.s5,
                                    "carbonEmissions": cmet.s6 * mul
                                    }
                                )
                            tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                            quarterData.append({
                                "label": cmet.s11,
                                "metrics": [
                                    {
                                        "label": "0",
                                        "value": [
                                            {
                                                "electricity": cmet.m1,
                                                "renewable": cmet.s12,
                                                "amtElectricity": cmet.m2,
                                                "spendElectricity": cmet.m3,
                                                "sqftSites": cmet.m4
                                            }
                                        ]
                                    },
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    },
                                    {
                                        "label": "2",
                                        "value": cmeas2
                                    },
                                    {
                                        "label": "3",
                                        "value": cmeas3NEW
                                    }
                                ]
                            })
                            tmeas.append({
                                        "label": cmet.s10,
                                        "value": quarterData
                            })
                            newMet = {
                                "label": "Electricity",
                                "metrics": tmeas
                            }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)
                else:
                    yearData = []
                    quarterData = []
                    cmeas = []
                    cmeas2 = []
                    cmeas3 = []
                    if cmet.label == "elecSpend":
                        tenID = ""
                        cfactor = ""
                        mul = 1
                        if cmet.s4 == "United States":
                            if use_new_carbon_factors(cmet.s10, cmet.s11):
                                tenID = "ZipsST_2023"
                            else:
                                tenID = "ZipsST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                kwH = cmet.s6 / float(cfactor["Average Electricity Price ($/kWh)"])
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                CE = mul * kwH * .001
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        elif cmet.s4 == "Canada":
                            if use_new_carbon_factors(cmet.s10, cmet.s11):
                                tenID = "CanadaST_2023"
                            else:
                                tenID = "CanadaST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                CE = mul * kwH * .001
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        else:
                            if use_new_carbon_factors(cmet.s10, cmet.s11):
                                tenID = "CountryCodes_2023"
                            else:
                                tenID = "CountryCodes_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                kwH = cmet.s6 / float(cfactor["Electricity Price per KWH"])
                                mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                CE = mul * kwH * .001
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        cmeas2NEW = []
                        cmeas2NEW.append({
                            "amountCurrency": cmet.s1,
                            "timePeriod": cmet.s3,
                            "country": cmet.s4,
                            "zipCode": cmet.s5,
                            "carbonEmissions": CE
                        }
                        )
                        tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "0",
                                    "value": [
                                        {
                                            "electricity": cmet.m1,
                                            "renewable": cmet.s12,
                                            "amtElectricity": cmet.m2,
                                            "spendElectricity": cmet.m3,
                                            "sqftSites": cmet.m4
                                        }
                                    ]
                                },
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2NEW
                                },
                                {
                                    "label": "3",
                                    "value": cmeas3
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        newMet = {
                            "label": "Electricity",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        tenID = ""
                        cfactor = ""
                        mul = 1
                        if cmet.s4 == "United States":
                            if use_new_carbon_factors(cmet.s10, cmet.s11):
                                tenID = "ZipsST_2023"
                            else:
                                tenID = "ZipsST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        elif cmet.s4 == "Canada":
                            if use_new_carbon_factors(cmet.s10, cmet.s11):
                                tenID = "CanadaST_2023"
                            else:
                                tenID = "CanadaST_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s5)    
                                mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        else:
                            if use_new_carbon_factors(cmet.s10, cmet.s11):
                                tenID = "CountryCodes_2023"
                            else:
                                tenID = "CountryCodes_2022"

                            try:
                                cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                            except exceptions.CosmosHttpResponseError as e:
                                logging.error('This is an error message for /carbonmeasure container10')
                                return {"url": "/", "atype": False}
                        cmeas3NEW = []
                        if cmet.label == "Size":
                            cmeas3NEW = []
                            cmeas3NEW.append({
                                    "squareFeet": cmet.s1,
                                    "unitMeasure": cmet.s14,
                                    "siteType": cmet.s2,
                                    "country": cmet.s4,
                                    "zipCode": cmet.s5,
                                    "carbonEmissions": cmet.s6 * mul
                                }
                            )
                        else:
                            cmeas3NEW = []
                            cmeas3NEW.append({
                                "squareFeet": cmet.s1,
                                "siteType": cmet.s2,
                                "country": cmet.s4,
                                "zipCode": cmet.s5,
                                "carbonEmissions": cmet.s6 * mul
                                }
                            )
                        tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "0",
                                    "value": [
                                        {
                                            "electricity": cmet.m1,
                                            "renewable": cmet.s12,
                                            "amtElectricity": cmet.m2,
                                            "spendElectricity": cmet.m3,
                                            "sqftSites": cmet.m4
                                        }
                                    ]
                                },
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                },
                                {
                                    "label": "3",
                                    "value": cmeas3NEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        newMet = {
                            "label": "Electricity",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteam":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "HeatSteam"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteam"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteam"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["amount"] != cmet.s7 or z["unitMeasure"] != cmet.s8 or z["timePeriod"] != cmet.s9]
                        cmeasNEW.append({
                            "heat": cmet.m1,
                            "amount": cmet.s1,
                            "unitMeasure": cmet.s2,
                            "timePeriod": cmet.s3,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "HeatSteam",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "heat": cmet.m1,
                            "amount": cmet.s1,
                            "unitMeasure": cmet.s2,
                            "timePeriod": cmet.s3,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "HeatSteam",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "heat": cmet.m1,
                        "amount": cmet.s1,
                        "unitMeasure": cmet.s2,
                        "timePeriod": cmet.s3,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "HeatSteam",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteamSpend" or cmet.metric == "HeatSteamNG":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != cmet.metric]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == cmet.metric]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == cmet.metric][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["amount"] != cmet.s7 or z["unitMeasure"] != cmet.s8 or z["timePeriod"] != cmet.s9 or z["siteType"] != cmet.s12]
                        cmeasNEW.append({
                            "heat": cmet.m1,
                            "naturalGas": cmet.m2,
                            "spend": cmet.m3,
                            "amount": cmet.s1,
                            "unitMeasure": cmet.s2,
                            "timePeriod": cmet.s3,
                            "siteType": cmet.s4,
                            "country": cmet.s5,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": cmet.metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "heat": cmet.m1,
                            "naturalGas": cmet.m2,
                            "spend": cmet.m3,
                            "amount": cmet.s1,
                            "unitMeasure": cmet.s2,
                            "timePeriod": cmet.s3,
                            "siteType": cmet.s4,
                            "country": cmet.s5,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": cmet.metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "heat": cmet.m1,
                        "naturalGas": cmet.m2,
                        "spend": cmet.m3,
                        "amount": cmet.s1,
                        "unitMeasure": cmet.s2,
                        "timePeriod": cmet.s3,
                        "siteType": cmet.s4,
                        "country": cmet.s5,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": cmet.metric,
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "AirTravel":
            user = {
            "id": db_result["id"],
            "email": db_result["email"],
            "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "AirTravel"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "AirTravel"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "AirTravel"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["longHaul"] != cmet.s7 or z["mediumHaul"] != cmet.s8 or z["shortHaul"] != cmet.s9]
                        cmeasNEW.append({
                            "air": cmet.m1,
                            "longHaul": cmet.s1,
                            "mediumHaul": cmet.s2,
                            "shortHaul": cmet.s3,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "AirTravel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "air": cmet.m1,
                            "longHaul": cmet.s1,
                            "mediumHaul": cmet.s2,
                            "shortHaul": cmet.s3,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "AirTravel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "air": cmet.m1,
                        "longHaul": cmet.s1,
                        "mediumHaul": cmet.s2,
                        "shortHaul": cmet.s3,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "AirTravel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "RailTravel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RailTravel"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RailTravel"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "RailTravel"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["transportType"] != cmet.s7 or z["distanceTraveled"] != cmet.s8 or z["unitMeasure"] != cmet.s9]
                        cmeasNEW.append({
                            "transportType": cmet.s1,
                            "distanceTraveled": cmet.s2,
                            "unitMeasure": cmet.s3,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "RailTravel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "transportType": cmet.s1,
                            "distanceTraveled": cmet.s2,
                            "unitMeasure": cmet.s3,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "RailTravel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "transportType": cmet.s1,
                        "distanceTraveled": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "RailTravel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Hotel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Hotel"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Hotel"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Hotel"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["hotels"] != cmet.s7]
                        cmeasNEW.append({
                            "hotels": cmet.s1,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Hotel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "hotels": cmet.s1,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Hotel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "hotels": cmet.s1,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "Hotel",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Commute":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Commute"]
            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Commute"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Commute"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["transportType"] != cmet.s7 or z["distanceTraveled"] != cmet.s8 or z["unitMeasure"] != cmet.s9]
                        cmeasNEW.append({
                            "transportType": cmet.s1,
                            "distanceTraveled": cmet.s2,
                            "unitMeasure": cmet.s3,
                            "numberEmployees": cmet.s4,
                            "daysWeek": cmet.s5,
                            "commute": cmet.m1,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Commute",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "transportType": cmet.s1,
                            "distanceTraveled": cmet.s2,
                            "unitMeasure": cmet.s3,
                            "numberEmployees": cmet.s4,
                            "daysWeek": cmet.s5,
                            "commute": cmet.m1,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Commute",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)                    
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "transportType": cmet.s1,
                        "distanceTraveled": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "numberEmployees": cmet.s4,
                        "daysWeek": cmet.s5,
                        "commute": cmet.m1,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "Commute",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Cloud":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Cloud"]
            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Cloud"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Cloud"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["google"] != cmet.s5 or z["aws"] != cmet.s7 or z["azure"] != cmet.s8 or z["oracle"] != cmet.s9 or z["usage"] != cmet.s12]
                        cmeasNEW.append({
                            "google": cmet.label,
                            "aws": cmet.s1,
                            "azure": cmet.s2,
                            "oracle": cmet.s3,
                            "usage": cmet.s4,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Cloud",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "google": cmet.label,
                            "aws": cmet.s1,
                            "azure": cmet.s2,
                            "oracle": cmet.s3,
                            "usage": cmet.s4,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Cloud",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "google": cmet.label,
                        "aws": cmet.s1,
                        "azure": cmet.s2,
                        "oracle": cmet.s3,
                        "usage": cmet.s4,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "Cloud",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Spend":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Spend"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Spend"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Spend"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["hotelSpend"] != cmet.s7 or z["airTravel"] != cmet.s8 or z["carTravel"] != cmet.s9 or z["currency"] != cmet.s12]
                        cmeasNEW.append({
                            "hotelSpend": cmet.s1,
                            "airTravel": cmet.s2,
                            "carTravel": cmet.s3,
                            "currency": cmet.s4,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Spend",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "hotelSpend": cmet.s1,
                            "airTravel": cmet.s2,
                            "carTravel": cmet.s3,
                            "currency": cmet.s4,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Spend",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "hotelSpend": cmet.s1,
                        "airTravel": cmet.s2,
                        "carTravel": cmet.s3,
                        "currency": cmet.s4,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "Spend",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "SpendAll":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SpendAll"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SpendAll"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "SpendAll"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["travelSpend"] != cmet.s7 or z["currency"] != cmet.s8]
                        cmeasNEW.append({
                            "travelSpend": cmet.s1,
                            "currency": cmet.s2,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "SpendAll",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "travelSpend": cmet.s1,
                            "currency": cmet.s2,
                            "carbonEmissions": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "SpendAll",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "travelSpend": cmet.s1,
                        "currency": cmet.s2,
                        "carbonEmissions": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "SpendAll",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "CompanySite":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CompanySite"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CompanySite"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CompanySite"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["name"] != cmet.s7 or z["type"] != cmet.s8 or z["country"] != cmet.s9]
                        cmeasNEW.append({
                            "name": cmet.s1,
                            "type": cmet.s2,
                            "country": cmet.s3,
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CompanySite",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "name": cmet.s1,
                            "type": cmet.s2,
                            "country": cmet.s3,
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CompanySite",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "name": cmet.s1,
                        "type": cmet.s2,
                        "country": cmet.s3,
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "CompanySite",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
        
"""
Endppoint use to edit the Scope 2 Emissions
"""
@carbonroute.post('/carbonmeasureedit2')
async def carbon_measure_edit2(cmet: CarbonMeasureEdit3):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasureedit')
        return {"url": "/", "atype": False}

    if "carbonmeasure" in db_result:
        if cmet.metric == "Electricity":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Electricity"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"]):
                elecData = [z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"][0]
                if ([a for a in elecData["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in elecData["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        qrt = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        if ([z for z in qrt["metrics"] if z["label"] == "1"]):
                            nmetlis = [z for z in qrt["metrics"] if z["label"] == "1"]
                            cmeas = nmetlis[0]["value"]
                            nmetlis2 = [z for z in qrt["metrics"] if z["label"] == "2"]
                            cmeas2 = nmetlis2[0]["value"]
                            nmetlis3 = [z for z in qrt["metrics"] if z["label"] == "3"]
                            cmeas3 = nmetlis3[0]["value"]
                            if cmet.label == "elecCons":
                                tenID = ""
                                cfactor = ""
                                mul = 1
                                if cmet.s4 == "United States":
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "ZipsST_2023"
                                    else:
                                        tenID = "ZipsST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                elif cmet.s4 == "Canada":
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "CanadaST_2023"
                                    else:
                                        tenID = "CanadaST_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                        mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                else:
                                    if use_new_carbon_factors(cmet.s10, cmet.s11):
                                        tenID = "CountryCodes_2023"
                                    else:
                                        tenID = "CountryCodes_2022"

                                    try:
                                        cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                        mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                    except exceptions.CosmosHttpResponseError as e:
                                        logging.error('This is an error message for /carbonmeasure container10')
                                        return {"url": "/", "atype": False}
                                cmeasNEW = [z for z in cmeas if z["amount"] != cmet.s7 or z["unitMeasure"] != cmet.s8 or z["country"] != cmet.s9 or z["zipCode"] != cmet.s13]
                                cmeasNEW.append({
                                                "amount": cmet.s1,
                                                "unitMeasure": cmet.s2,
                                                "timePeriod": cmet.s3,
                                                "country": cmet.s4,
                                                "zipCode": cmet.s5,
                                                "carbonEmissions": cmet.s6 * mul
                                            }
                                )
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                                quarterData.append({
                                    "label": cmet.s11,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s12,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeasNEW
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s10,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
                    else:
                        qrt = []
                        cmeas = []
                        cmeas2 = []
                        cmeas3 = []
                        if cmet.label == "elecCons":
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CanadaST_2023"
                                else:
                                    tenID = "CanadaST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            cmeasNEW = []
                            cmeasNEW.append({
                                "amount": cmet.s1,
                                "unitMeasure": cmet.s2,
                                "timePeriod": cmet.s3,
                                "country": cmet.s4,
                                "zipCode": cmet.s5,
                                "carbonEmissions": cmet.s6 * mul
                            }
                            )
                            tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                            quarterData.append({
                                "label": cmet.s11,
                                "metrics": [
                                    {
                                        "label": "0",
                                        "value": [
                                            {
                                                "electricity": cmet.m1,
                                                "renewable": cmet.s12,
                                                "amtElectricity": cmet.m2,
                                                "spendElectricity": cmet.m3,
                                                "sqftSites": cmet.m4
                                            }
                                        ]
                                    },
                                    {
                                        "label": "1",
                                        "value": cmeasNEW
                                    },
                                    {
                                        "label": "2",
                                        "value": cmeas2
                                    },
                                    {
                                        "label": "3",
                                        "value": cmeas3
                                    }
                                ]
                            })
                            tmeas.append({
                                        "label": cmet.s10,
                                        "value": quarterData
                            })
                            newMet = {
                                "label": "Electricity",
                                "metrics": tmeas
                            }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)
                else:  
                    yearData = [aa for aa in elecData["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    qrt = []
                    if ([z for z in qrt["metrics"] if z["label"] == "1"]):
                        cmeas = []
                        cmeas2 = []
                        cmeas3 = []
                        if cmet.label == "elecCons":
                            tenID = ""
                            cfactor = ""
                            mul = 1
                            if cmet.s4 == "United States":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "ZipsST_2023"
                                else:
                                    tenID = "ZipsST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            elif cmet.s4 == "Canada":
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CanadaST_2023"
                                else:
                                    tenID = "CanadaST_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s5)
                                    mul = float(cfactor["CarbonFactors(kgCO2e/kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            else:
                                if use_new_carbon_factors(cmet.s10, cmet.s11):
                                    tenID = "CountryCodes_2023"
                                else:
                                    tenID = "CountryCodes_2022"

                                try:
                                    cfactor = read_item(callConnect.container10, tenID, cmet.s4)
                                    mul = float(cfactor["Electricity Emissions Factor (kgCO2e per kWh)"])
                                except exceptions.CosmosHttpResponseError as e:
                                    logging.error('This is an error message for /carbonmeasure container10')
                                    return {"url": "/", "atype": False}
                            cmeasNEW = []
                            cmeasNEW.append({
                                "amount": cmet.s1,
                                "unitMeasure": cmet.s2,
                                "timePeriod": cmet.s3,
                                "country": cmet.s4,
                                "zipCode": cmet.s5,
                                "carbonEmissions": cmet.s6 * mul
                            }
                            )
                            tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s10]
                            quarterData.append({
                                "label": cmet.s11,
                                "metrics": [
                                    {
                                        "label": "0",
                                        "value": [
                                            {
                                                "electricity": cmet.m1,
                                                "renewable": cmet.s12,
                                                "amtElectricity": cmet.m2,
                                                "spendElectricity": cmet.m3,
                                                "sqftSites": cmet.m4
                                            }
                                        ]
                                    },
                                    {
                                        "label": "1",
                                        "value": cmeasNEW
                                    },
                                    {
                                        "label": "2",
                                        "value": cmeas2
                                    },
                                    {
                                        "label": "3",
                                        "value": cmeas3
                                    }
                                ]
                            })
                            tmeas.append({
                                        "label": cmet.s10,
                                        "value": quarterData
                            })
                            newMet = {
                                "label": "Electricity",
                                "metrics": tmeas
                            }
                            mets.append(newMet)
                            target = {
                                "carbonmeasure": mets
                            }
                            user.update(target)
                            callConnect.container7.upsert_item(body=user)


"""
Endppoint use to delete the Scope 2 Emissions
"""
@carbonroute.post('/carbonmeasuredelete')
async def carbon_measure_delete(cmet: CarbonMeasure):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasuredelete')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CarbonInit":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonInit"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CarbonInit"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CarbonInit"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        
                        cmeasNEW = []
                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CarbonInit",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "RemoteWorkers":
            user = {
            "id": db_result["id"],
            "email": db_result["email"],
            "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RemoteWorkers"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkers"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "RemoteWorkers"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["remoteWorkersFull"] != cmet.s1 or z["remoteWorkersPart"] != cmet.s2 or z["country"] != cmet.s3]
                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "RemoteWorkers",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Electricity":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Electricity"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"]):
                elecData = [z for z in db_result["carbonmeasure"] if z["label"] == "Electricity"][0]
                
                if ([a for a in elecData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in elecData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        qrt = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        if ([z for z in qrt["metrics"] if z["label"] == "1"]):
                            nmetlis = [z for z in qrt["metrics"] if z["label"] == "1"]
                            cmeas = nmetlis[0]["value"]

                            nmetlis2 = [z for z in qrt["metrics"] if z["label"] == "2"]
                            cmeas2 = nmetlis2[0]["value"]

                            nmetlis3 = [z for z in qrt["metrics"] if z["label"] == "3"]
                            cmeas3 = nmetlis3[0]["value"]
                            if cmet.label == "elecCons":
                                cmeasNEW = [z for z in cmeas if z["amount"] != cmet.s1 or z["unitMeasure"] != cmet.s2 or z["country"] != cmet.s4 or z["zipCode"] != cmet.s5]
                                
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s7]
                                quarterData.append({
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeasNEW
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s7,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)     
                            elif cmet.label == "elecSpend":
                                cmeas2NEW = [z for z in cmeas2 if z["amountCurrency"] != cmet.s1 or z["timePeriod"] != cmet.s3 or z["country"] != cmet.s4 or z["zipCode"] != cmet.s5]
                                
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s7]
                                quarterData.append({
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2NEW
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s7,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)

                            else:
                                cmeas3NEW = [z for z in cmeas3 if z["squareFeet"] != cmet.s1 or z["siteType"] != cmet.s2 or z["country"] != cmet.s4 or z["zipCode"] != cmet.s5]
                                if (cmet.s10):
                                    cmeas3NEW = [z for z in cmeas3 if z["squareFeet"] != cmet.s1 or z["siteType"] != cmet.s2 or z["country"] != cmet.s4 or z["zipCode"] != cmet.s5 or z["unitMeasure"] != cmet.s10]
                                else:
                                    cmeas3NEW = [z for z in cmeas3 if z["squareFeet"] != cmet.s1 or z["siteType"] != cmet.s2 or z["country"] != cmet.s4 or z["zipCode"] != cmet.s5]
                                tmeas = [a for a in elecData["metrics"] if a["label"] != cmet.s7]
                                quarterData.append({
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "0",
                                            "value": [
                                                {
                                                    "electricity": cmet.m1,
                                                    "renewable": cmet.s9,
                                                    "amtElectricity": cmet.m2,
                                                    "spendElectricity": cmet.m3,
                                                    "sqftSites": cmet.m4
                                                }
                                            ]
                                        },
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        },
                                        {
                                            "label": "2",
                                            "value": cmeas2
                                        },
                                        {
                                            "label": "3",
                                            "value": cmeas3NEW
                                        }
                                    ]
                                })
                                tmeas.append({
                                            "label": cmet.s7,
                                            "value": quarterData
                                })
                                newMet = {
                                    "label": "Electricity",
                                    "metrics": tmeas
                                }
                                mets.append(newMet)
                                target = {
                                    "carbonmeasure": mets
                                }
                                user.update(target)
                                callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteam":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "HeatSteam"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteam"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "HeatSteam"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["amount"] != cmet.s1 or z["unitMeasure"] != cmet.s2 or z["timePeriod"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "HeatSteam",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "HeatSteamSpend" or cmet.metric == "HeatSteamNG":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != cmet.metric]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == cmet.metric]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == cmet.metric][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["amount"] != cmet.s1 or z["unitMeasure"] != cmet.s2 or z["timePeriod"] != cmet.s3 or z["siteType"] != cmet.s4 or z["country"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": cmet.metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "AirTravel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "AirTravel"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "AirTravel"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "AirTravel"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["longHaul"] != cmet.s1 or z["mediumHaul"] != cmet.s2 or z["shortHaul"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "AirTravel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "RailTravel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "RailTravel"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "RailTravel"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "RailTravel"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["transportType"] != cmet.s1 or z["distanceTraveled"] != cmet.s2 or z["unitMeasure"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "RailTravel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Hotel":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Hotel"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Hotel"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Hotel"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["hotels"] != cmet.s1]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Hotel",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Commute":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Commute"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Commute"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Commute"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["transportType"] != cmet.s1 or z["distanceTraveled"] != cmet.s2 or z["unitMeasure"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Commute",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Cloud":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Cloud"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Cloud"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Cloud"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["google"] != cmet.s1 or z["aws"] != cmet.s2 or z["azure"] != cmet.s3 or z["oracle"] != cmet.s4 or z["usage"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Cloud",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "Spend":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Spend"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Spend"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Spend"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["hotelSpend"] != cmet.s1 or z["airTravel"] != cmet.s2 or z["carTravel"] != cmet.s3 or z["currency"] != cmet.s4]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "Spend",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "SpendAll":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SpendAll"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SpendAll"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "SpendAll"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["travelSpend"] != cmet.s1 or z["currency"] != cmet.s2]                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "SpendAll",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        elif cmet.metric == "CompanySite":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CompanySite"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CompanySite"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CompanySite"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        # cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for i,z in enumerate(cmeas) if str(i) != cmet.s4]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CompanySite",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
        



"""
Endpoint used to update the scope 3 y/n metric.
"""
@carbonroute.post('/carbonmeasureFROG')
async def carbon_measure_frog(cmet: CarbonMeasure):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasure')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "Emissions":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Emissions"]
            scope3M = "Yes" if cmet.m1 == True else "No"
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Emissions"]):
                emData = [z for z in db_result["carbonmeasure"] if z["label"] == "Emissions"][0]

                if ([a for a in emData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in emData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = [
                        {
                            "scope1": cmet.s1,
                            "scope2": cmet.s2,
                            "scope3": cmet.s3,
                            "scope3M": scope3M
                        }
                    ]
                    tmeas = [a for a in emData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Emissions",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "scope1": cmet.s1,
                        "scope2": cmet.s2,
                        "scope3": cmet.s3,
                        "scope3M": scope3M
                    }]
                    tmeas = [a for a in emData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Emissions",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Emissions"]
                newMet = {
                    "label": "Emissions",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "scope1": cmet.s1,
                                                        "scope2": cmet.s2,
                                                        "scope3": cmet.s3,
                                                        "scope3M": scope3M
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)


"""
Endpoint used to update the target metrics.
"""
@carbonroute.post('/carbonmeasureman')
async def carbon_measure(cmet: CarbonMeasureMAN):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasure')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CarbonScopes":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            try:
                db_resultC = read_item(callConnect.container7, cmet.oid, cmet.email)
            except exceptions.CosmosHttpResponseError as e:
                logging.error('This is an error message for /carbonmeasure')
                return {"url": "/", "atype": False}

            if "carbonmeasure" in db_resultC:
                user2C = {
                    "id": db_resultC["id"],
                    "email": db_resultC["email"],
                    "carbonmeasure": []
                }
                mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                
                if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                    emData = [z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"][0]

                    if ([a for a in emData["metrics"] if a["label"] == cmet.s7]):
                        yearData2C = [aa for aa in emData["metrics"] if aa["label"] == cmet.s7][0]
                        if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s8]):
                            pass
                        else:
                            quarterData2C = [bb for bb in yearData2C["value"] if bb["label"] != cmet.s8]
                            cmeas2C = []
                            cmeas2C.append({
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            })
                            tmeas2C = [a for a in emData["metrics"] if a["label"] != cmet.s7]
                            quarterData2C.append({
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas2C
                                    }
                                ]
                            })
                            tmeas2C.append({
                                "label": cmet.s7,
                                "value": quarterData2C
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)
                    else:
                        cmeas2C = [{
                            "scope1": 0,
                            "scope2": 0,
                            "scope3": 0
                        }]
                        tmeas2C = [a for a in emData["metrics"] if a["label"] != cmet.s7]
                        tmeas2C.append({
                                    "label": cmet.s7,
                                    "value": [
                                        {
                                            "label": cmet.s8,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value": cmeas2C
                                                }
                                            ]
                                        }
                                    ]
                                })
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": tmeas2C
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)
                
                else:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                    newMet2C = {
                        "label": "Emissions",
                        "metrics": [
                            {
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "scope1": 0,
                                                            "scope2": 0,
                                                            "scope3": 0
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets2C.append(newMet2C)
                    target2C = {
                        "carbonmeasure": mets2C
                    }
                    user2C.update(target2C)
                    callConnect.container7.upsert_item(body=user2C)

            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonScopes"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CarbonScopes"]):
                remoteData = [z for z in db_result["carbonmeasure"] if z["label"] == "CarbonScopes"][0]

                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = [{
                        "CV": cmet.s1,
                        "SE": cmet.s2,
                        "REF": cmet.s3,
                        "CM": cmet.s4,
                        "Other": cmet.s5,
                        "RemoteEmployees": cmet.s6,
                        "ElecCon": cmet.s9,
                        "HeatSteam": cmet.s10,
                        "Other2": cmet.s11,
                        "BT": cmet.s12,
                        "EC": cmet.s13,
                        "CE": cmet.s14,
                        "Other3": cmet.s15
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CarbonScopes",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = [{
                        "CV": cmet.s1,
                        "SE": cmet.s2,
                        "REF": cmet.s3,
                        "CM": cmet.s4,
                        "Other": cmet.s5,
                        "RemoteEmployees": cmet.s6,
                        "ElecCon": cmet.s9,
                        "HeatSteam": cmet.s10,
                        "Other2": cmet.s11,
                        "BT": cmet.s12,
                        "EC": cmet.s13,
                        "CE": cmet.s14,
                        "Other3": cmet.s15
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "CarbonScopes",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CarbonScopes"]
                newMet = {
                    "label": "CarbonScopes",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "CV": cmet.s1,
                                                        "SE": cmet.s2,
                                                        "REF": cmet.s3,
                                                        "CM": cmet.s4,
                                                        "Other": cmet.s5,
                                                        "RemoteEmployees": cmet.s6,
                                                        "ElecCon": cmet.s9,
                                                        "HeatSteam": cmet.s10,
                                                        "Other2": cmet.s11,
                                                        "BT": cmet.s12,
                                                        "EC": cmet.s13,
                                                        "CE": cmet.s14,
                                                        "Other3": cmet.s15
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        


"""
Endpoint used to add carbon measurements for company vehicles
"""
@carbonroute.post('/carbonmeasurecv')
async def company_vehicle(cmet: CarbonMeasureCV):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurecv')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CV":
            if cmet.part == "1":
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CV"]
                if ([z for z in db_result["carbonmeasure"] if z["label"] == "CV"]):
                    nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CV"][0]

                    if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                        cmeas = []
                        cmeas2 = []
                        if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas2 = myData["metrics"][1]["value"]
                        cmeas.append({
                            "fuelType": cmet.s1,
                            "fuelQuantity": cmet.s2,
                            "unitMeasure": cmet.s3,
                            "timePeriod": cmet.s4,
                            "carbonEmissions": cmet.s5,
                            "carbonFactor": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        cmeas = []
                        cmeas2 = []
                        quarterData = []
                        cmeas.append({
                            "fuelType": cmet.s1,
                            "fuelQuantity": cmet.s2,
                            "unitMeasure": cmet.s3,
                            "timePeriod": cmet.s4,
                            "carbonEmissions": cmet.s5,
                            "carbonFactor": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)

                else:
                    cmeas = []
                    cmeas2 = []
                    quarterData = []
                    cmeas.append({
                        "fuelType": cmet.s1,
                        "fuelQuantity": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "timePeriod": cmet.s4,
                        "carbonEmissions": cmet.s5,
                        "carbonFactor": cmet.s6
                    })
                    tmeas = []
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            },
                            {
                                "label": "2",
                                "value": cmeas2
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "CV",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)

            else:
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CV"]
                if ([z for z in db_result["carbonmeasure"] if z["label"] == "CV"]):
                    nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CV"][0]
                    
                    if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                        cmeas = []
                        cmeas2 = []
                        if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas2 = myData["metrics"][1]["value"]
                        if (cmet.s9):
                            cmeas2.append({
                                "fuelType": cmet.s1,
                                "unitMeasure": cmet.s9,
                                "passengerCars": cmet.s2,
                                "milesTraveled": cmet.s3,
                                "timePeriod": cmet.s4,
                                "carbonEmissions": cmet.s5,
                                "carbonFactor": cmet.s6
                            })
                        else:
                            cmeas2.append({
                                "fuelType": cmet.s1,
                                "passengerCars": cmet.s2,
                                "milesTraveled": cmet.s3,
                                "timePeriod": cmet.s4,
                                "carbonEmissions": cmet.s5,
                                "carbonFactor": cmet.s6
                            })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        cmeas = []
                        cmeas2 = []
                        quarterData = []
                        if (cmet.s9):
                            cmeas2.append({
                                "fuelType": cmet.s1,
                                "unitMeasure": cmet.s9,
                                "passengerCars": cmet.s2,
                                "milesTraveled": cmet.s3,
                                "timePeriod": cmet.s4,
                                "carbonEmissions": cmet.s5,
                                "carbonFactor": cmet.s6
                            })
                        else:
                            cmeas2.append({
                                "fuelType": cmet.s1,
                                "passengerCars": cmet.s2,
                                "milesTraveled": cmet.s3,
                                "timePeriod": cmet.s4,
                                "carbonEmissions": cmet.s5,
                                "carbonFactor": cmet.s6
                            })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = []
                    cmeas2 = []
                    quarterData = []
                    if (cmet.s9):
                        cmeas2.append({
                            "fuelType": cmet.s1,
                            "unitMeasure": cmet.s9,
                            "passengerCars": cmet.s2,
                            "milesTraveled": cmet.s3,
                            "timePeriod": cmet.s4,
                            "carbonEmissions": cmet.s5,
                            "carbonFactor": cmet.s6
                        })
                    else:
                        cmeas2.append({
                            "fuelType": cmet.s1,
                            "passengerCars": cmet.s2,
                            "milesTraveled": cmet.s3,
                            "timePeriod": cmet.s4,
                            "carbonEmissions": cmet.s5,
                            "carbonFactor": cmet.s6
                        })
                    tmeas = []
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            },
                            {
                                "label": "2",
                                "value": cmeas2
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "CV",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)


"""
Endpoint used to edit the carbon measurements for company vehicles
"""
@carbonroute.post('/carbonmeasurecvedit')
async def company_vehicle(cmet: CarbonMeasureEdit):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurecvedit')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CV":
            if cmet.part == "1":
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CV"]
                if ([z for z in db_result["carbonmeasure"] if z["label"] == "CV"]):
                    nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CV"][0]
                    if ([a for a in nmet["metrics"] if a["label"] == cmet.s11]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s11][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s12]
                        cmeas = []
                        cmeas2 = []
                        cmeasNEW = []
                        if ([bb for bb in yearData["value"] if bb["label"] == cmet.s12]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s12][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas2 = myData["metrics"][1]["value"]
                            cmeasNEW = [z for z in cmeas if z["fuelType"] != cmet.s1 or z["fuelQuantity"] != cmet.s2 or z["unitMeasure"] != cmet.s3]

                        cmeasNEW.append({
                            "fuelType": cmet.s5,
                            "fuelQuantity": cmet.s6,
                            "unitMeasure": cmet.s7,
                            "timePeriod": cmet.s8,
                            "carbonEmissions": cmet.s9,
                            "carbonFactor": cmet.s10
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                        quarterData.append({
                            "label": cmet.s12,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s11,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    else:
                        quarterData = []
                        cmeas = []
                        cmeas2 = []
                        cmeasNEW = []
                        cmeasNEW.append({
                            "fuelType": cmet.s5,
                            "fuelQuantity": cmet.s6,
                            "unitMeasure": cmet.s7,
                            "timePeriod": cmet.s8,
                            "carbonEmissions": cmet.s9,
                            "carbonFactor": cmet.s10
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                        quarterData.append({
                            "label": cmet.s12,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s11,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
                    
            else:
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CV"]
                if ([z for z in db_result["carbonmeasure"] if z["label"] == "CV"]):
                    nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CV"][0]
                    if ([a for a in nmet["metrics"] if a["label"] == cmet.s11]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s11][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s12]
                        cmeas = []
                        cmeas2 = []
                        cmeasNEW = []
                        if ([bb for bb in yearData["value"] if bb["label"] == cmet.s12]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s12][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas2 = myData["metrics"][1]["value"]
                            cmeasNEW = []
                            if (cmet.s13):
                                cmeasNEW = [z for z in cmeas2 if z["fuelType"] != cmet.s1 or z["passengerCars"] != cmet.s2 or z["milesTraveled"] != cmet.s3 or z["unitMeasure"] != cmet.s13]
                            else:
                                cmeasNEW = [z for z in cmeas2 if z["fuelType"] != cmet.s1 or z["passengerCars"] != cmet.s2 or z["milesTraveled"] != cmet.s3]

                        if (cmet.s13):
                            cmeasNEW.append({
                                "fuelType": cmet.s5,
                                "unitMeasure": cmet.s14,
                                "passengerCars": cmet.s6,
                                "milesTraveled": cmet.s7,
                                "timePeriod": cmet.s8,
                                "carbonEmissions": cmet.s9,
                                "carbonFactor": cmet.s10
                            })
                        else:
                            cmeasNEW.append({
                                "fuelType": cmet.s5,
                                "passengerCars": cmet.s6,
                                "milesTraveled": cmet.s7,
                                "timePeriod": cmet.s8,
                                "carbonEmissions": cmet.s9,
                                "carbonFactor": cmet.s10
                            })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                        quarterData.append({
                            "label": cmet.s12,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s11,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)                        
                    else:
                        yearData = []
                        quarterData = []
                        cmeas = []
                        cmeas2 = []
                        cmeasNEW = []
                        if (cmet.s13):
                            cmeasNEW.append({
                                "fuelType": cmet.s5,
                                "unitMeasure": cmet.s14,
                                "passengerCars": cmet.s6,
                                "milesTraveled": cmet.s7,
                                "timePeriod": cmet.s8,
                                "carbonEmissions": cmet.s9,
                                "carbonFactor": cmet.s10
                            })
                        else:
                            cmeasNEW.append({
                                "fuelType": cmet.s5,
                                "passengerCars": cmet.s6,
                                "milesTraveled": cmet.s7,
                                "timePeriod": cmet.s8,
                                "carbonEmissions": cmet.s9,
                                "carbonFactor": cmet.s10
                            })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                        quarterData.append({
                            "label": cmet.s12,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s11,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)                        


"""
Endpoint used to delete the carbon measurements for company vehicles
"""
@carbonroute.post('/carbonmeasurecvdel')
async def company_vehicle(cmet: CarbonMeasureCV):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurecvdel')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CV":
            if cmet.part == "1":
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CV"]
                if ([z for z in db_result["carbonmeasure"] if z["label"] == "CV"]):
                    nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CV"][0]

                    if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                        cmeas = []
                        cmeas2 = []
                        cmeasNEW = []
                        if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas2 = myData["metrics"][1]["value"]
                            cmeasNEW = [z for z in cmeas if z["fuelType"] != cmet.s1 or z["fuelQuantity"] != cmet.s2 or z["unitMeasure"] != cmet.s3]
                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                },
                                {
                                    "label": "2",
                                    "value": cmeas2
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)
            else:
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CV"]
                if ([z for z in db_result["carbonmeasure"] if z["label"] == "CV"]):
                    nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CV"][0]

                    if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                        cmeas = []
                        cmeas2 = []
                        cmeasNEW = []
                        if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas2 = myData["metrics"][1]["value"]
                            cmeasNEW = []
                            if (cmet.s9):
                                cmeasNEW = [z for z in cmeas2 if z["fuelType"] != cmet.s1 or z["passengerCars"] != cmet.s2 or z["milesTraveled"] != cmet.s3 or z["unitMeasure"] != cmet.s9]
                            else:
                                cmeasNEW = [z for z in cmeas2 if z["fuelType"] != cmet.s1 or z["passengerCars"] != cmet.s2 or z["milesTraveled"] != cmet.s3]
                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                },
                                {
                                    "label": "2",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                        }
                        newMet = {
                            "label": "CV",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "carbonmeasure": mets
                        }
                        user.update(target)
                        callConnect.container7.upsert_item(body=user)


"""
Endpoint used to add carbon measurements for stationary equipment
"""
@carbonroute.post('/carbonmeasurese')
async def stationary_equipment(cmet: CarbonMeasureSE):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurese')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "SE":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SE"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SE"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "SE"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "fuelType": cmet.s1,
                        "fuelQuantity": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "timePeriod": cmet.s4,
                        "carbonEmissions": cmet.s5,
                        "carbonFactor": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "SE",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = []
                    quarterData = []
                    cmeas.append({
                        "fuelType": cmet.s1,
                        "fuelQuantity": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "timePeriod": cmet.s4,
                        "carbonEmissions": cmet.s5,
                        "carbonFactor": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "SE",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)

            else:
                cmeas = []
                quarterData = []
                cmeas.append({
                    "fuelType": cmet.s1,
                    "fuelQuantity": cmet.s2,
                    "unitMeasure": cmet.s3,
                    "timePeriod": cmet.s4,
                    "carbonEmissions": cmet.s5,
                    "carbonFactor": cmet.s6
                })
                tmeas = []
                quarterData.append({
                    "label": cmet.s8,
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                })
                tmeas.append({
                    "label": cmet.s7,
                    "value": quarterData
                })
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "carbonmeasure": []
                }
                newMet = {
                    "label": "SE",
                    "metrics": tmeas
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
            
"""
Endpoint used to update to edit the carbon measurements for stationary equipment
"""
@carbonroute.post('/carbonmeasureseedit')
async def stationary_equipment_edit(cmet: CarbonMeasureSEEdit):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasureseedit')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "SE":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SE"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SE"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "SE"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s11]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s11][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s12]
                    cmeas = []
                    cmeasNEW = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s12]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s12][0]
                        cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["fuelType"] != cmet.s1 or z["fuelQuantity"] != cmet.s2 or z["unitMeasure"] != cmet.s3]
                    cmeasNEW.append({
                        "fuelType": cmet.s5,
                        "fuelQuantity": cmet.s6,
                        "unitMeasure": cmet.s7,
                        "timePeriod": cmet.s8,
                        "carbonEmissions": cmet.s9,
                        "carbonFactor": cmet.s10
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                    quarterData.append({
                        "label": cmet.s12,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s11,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "SE",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    yearData = []
                    quarterData = []
                    cmeas = []
                    cmeasNEW = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s12]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s12][0]
                        cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["fuelType"] != cmet.s1 or z["fuelQuantity"] != cmet.s2 or z["unitMeasure"] != cmet.s3]
                    cmeasNEW.append({
                        "fuelType": cmet.s5,
                        "fuelQuantity": cmet.s6,
                        "unitMeasure": cmet.s7,
                        "timePeriod": cmet.s8,
                        "carbonEmissions": cmet.s9,
                        "carbonFactor": cmet.s10
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                    quarterData.append({
                        "label": cmet.s12,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s11,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "SE",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)

"""
Endpoint used to update to delete the carbon measurements for stationary equipment
"""
@carbonroute.post('/carbonmeasuresedel')
async def stationary_equipment_delete(cmet: CarbonMeasureSE):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasuredel')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "SE":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "SE"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "SE"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "SE"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["fuelType"] != cmet.s1 or z["fuelQuantity"] != cmet.s2 or z["unitMeasure"] != cmet.s3]
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "SE",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)



"""
Endpoint used to update the target metrics.
"""
@carbonroute.post('/carbonmeasurecm')
async def company_manufacture(cmet: CompanyManufactured):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurecm')
        return {"url": "/", "atype": False}

    if "carbonmeasure" in db_result:
        if cmet.metric == "CM":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CM"]

            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CM"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "CM"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s12]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s12][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s13]
                    
                    cmeas = [
                        {
                        "label": "aluminum",
                        "value": cmet.m1
                    },
                    {
                        "label": "aluminumQuantity",
                        "value": cmet.s1
                    },
                    {
                        "label": "iron",
                        "value": cmet.m2
                    },
                    {
                        "label": "ironQuantity",
                        "value": cmet.s2
                    },
                    {
                        "label": "nitric",
                        "value": cmet.m3
                    },
                    {
                        "label": "nitricQuantity",
                        "value": cmet.s3
                    },
                    {
                        "label": "ammonia",
                        "value": cmet.m4
                    },
                    {
                        "label": "ammoniaQuantity",
                        "value": cmet.s4
                    },
                    {
                        "label": "adipic",
                        "value": cmet.m5
                    },
                    {
                        "label": "adipicQuantity",
                        "value": cmet.s5
                    },
                    {
                        "label": "cement",
                        "value": cmet.m6
                    },
                    {
                        "label": "cementQuantity",
                        "value": cmet.s6
                    },
                    {
                        "label": "lime",
                        "value": cmet.m7
                    },
                    {
                        "label": "limeQuantity",
                        "value": cmet.s7
                    },
                    {
                        "label": "hcfc",
                        "value": cmet.m8
                    },
                    {
                        "label": "hcfcQuantity",
                        "value": cmet.s8
                    },
                    {
                        "label": "pulp",
                        "value": cmet.m9
                    },
                    {
                        "label": "pulpQuantity",
                        "value": cmet.s9
                    },
                    {
                        "label": "semiconductors",
                        "value": cmet.m10
                    },
                    {
                        "label": "semiconductorsQuantity",
                        "value": cmet.s10
                    },
                    {
                        "label": "noneAbove",
                        "value": cmet.m11
                    },
                    {
                        "label": "timePeriod",
                        "value": cmet.s11
                    }
                    ]
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s12]
                    quarterData.append({
                        "label": cmet.s13,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s12,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "CM",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    quarterData = []
                    cmeas = [
                        {
                        "label": "aluminum",
                        "value": cmet.m1
                        },
                        {
                            "label": "aluminumQuantity",
                            "value": cmet.s1
                        },
                        {
                            "label": "iron",
                            "value": cmet.m2
                        },
                        {
                            "label": "ironQuantity",
                            "value": cmet.s2
                        },
                        {
                            "label": "nitric",
                            "value": cmet.m3
                        },
                        {
                            "label": "nitricQuantity",
                            "value": cmet.s3
                        },
                        {
                            "label": "ammonia",
                            "value": cmet.m4
                        },
                        {
                            "label": "ammoniaQuantity",
                            "value": cmet.s4
                        },
                        {
                            "label": "adipic",
                            "value": cmet.m5
                        },
                        {
                            "label": "adipicQuantity",
                            "value": cmet.s5
                        },
                        {
                            "label": "cement",
                            "value": cmet.m6
                        },
                        {
                            "label": "cementQuantity",
                            "value": cmet.s6
                        },
                        {
                            "label": "lime",
                            "value": cmet.m7
                        },
                        {
                            "label": "limeQuantity",
                            "value": cmet.s7
                        },
                        {
                            "label": "hcfc",
                            "value": cmet.m8
                        },
                        {
                            "label": "hcfcQuantity",
                            "value": cmet.s8
                        },
                        {
                            "label": "pulp",
                            "value": cmet.m9
                        },
                        {
                            "label": "pulpQuantity",
                            "value": cmet.s9
                        },
                        {
                            "label": "semiconductors",
                            "value": cmet.m10
                        },
                        {
                            "label": "semiconductorsQuantity",
                            "value": cmet.s10
                        },
                        {
                            "label": "noneAbove",
                            "value": cmet.m11
                        },
                        {
                            "label": "timePeriod",
                            "value": cmet.s11
                        }   
                    ]
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s12]
                    quarterData.append({
                        "label": cmet.s13,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s12,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "CM",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)

            else:
                cmeas = []
                quarterData = []
                cmeas = [
                    {
                        "label": "aluminum",
                        "value": cmet.m1
                    },
                    {
                        "label": "aluminumQuantity",
                        "value": cmet.s1
                    },
                    {
                        "label": "iron",
                        "value": cmet.m2
                    },
                    {
                        "label": "ironQuantity",
                        "value": cmet.s2
                    },
                    {
                        "label": "nitric",
                        "value": cmet.m3
                    },
                    {
                        "label": "nitricQuantity",
                        "value": cmet.s3
                    },
                    {
                        "label": "ammonia",
                        "value": cmet.m4
                    },
                    {
                        "label": "ammoniaQuantity",
                        "value": cmet.s4
                    },
                    {
                        "label": "adipic",
                        "value": cmet.m5
                    },
                    {
                        "label": "adipicQuantity",
                        "value": cmet.s5
                    },
                    {
                        "label": "cement",
                        "value": cmet.m6
                    },
                    {
                        "label": "cementQuantity",
                        "value": cmet.s6
                    },
                    {
                        "label": "lime",
                        "value": cmet.m7
                    },
                    {
                        "label": "limeQuantity",
                        "value": cmet.s7
                    },
                    {
                        "label": "hcfc",
                        "value": cmet.m8
                    },
                    {
                        "label": "hcfcQuantity",
                        "value": cmet.s8
                    },
                    {
                        "label": "pulp",
                        "value": cmet.m9
                    },
                    {
                        "label": "pulpQuantity",
                        "value": cmet.s9
                    },
                    {
                        "label": "semiconductors",
                        "value": cmet.m10
                    },
                    {
                        "label": "semiconductorsQuantity",
                        "value": cmet.s10
                    },
                    {
                        "label": "noneAbove",
                        "value": cmet.m11
                    },
                    {
                        "label": "timePeriod",
                        "value": cmet.s11
                    }
                ]
                tmeas = []
                quarterData.append({
                    "label": cmet.s13,
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                })
                tmeas.append({
                    "label": cmet.s12,
                    "value": quarterData
                })
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "carbonmeasure": []
                }
                newMet = {
                    "label": "CM",
                    "metrics": tmeas
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
        

"""
Endpoint used to update the carbon vehicle metrics from the Carbon Measurement Feature.
"""
@carbonroute.post('/carbonmeasureref')
async def refrigerant(cmet: CarbonMeasureSE):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasureref')
        return {"url": "/", "atype": False}

    if "carbonmeasure" in db_result:
        if cmet.metric == "REF":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "REF"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "REF"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "REF"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "typeRefrigerant": cmet.s1,
                        "amountRefrigerant": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "timePeriod": cmet.s4,
                        "carbonEmissions": cmet.s5,
                        "gwp": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "REF",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    cmeas = []
                    quarterData = []
                    cmeas.append({
                        "typeRefrigerant": cmet.s1,
                        "amountRefrigerant": cmet.s2,
                        "unitMeasure": cmet.s3,
                        "timePeriod": cmet.s4,
                        "carbonEmissions": cmet.s5,
                        "gwp": cmet.s6
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "REF",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                    
            else:
                cmeas = []
                quarterData = []
                cmeas.append({
                    "typeRefrigerant": cmet.s1,
                    "amountRefrigerant": cmet.s2,
                    "unitMeasure": cmet.s3,
                    "timePeriod": cmet.s4,
                    "carbonEmissions": cmet.s5,
                    "gwp": cmet.s6
                })
                tmeas = []
                quarterData.append({
                    "label": cmet.s8,
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                })
                tmeas.append({
                    "label": cmet.s7,
                    "value": quarterData
                })
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "carbonmeasure": []
                }
                newMet = {
                    "label": "REF",
                    "metrics": tmeas
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)

@carbonroute.post('/carbonmeasurerefdel')
async def add_goal(cmet: CarbonMeasureSE):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)        

    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurerefdel')
        return {"url": "/", "atype": False}

    if "carbonmeasure" in db_result: 
        if cmet.metric == "REF":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "REF"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "REF"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "REF"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["typeRefrigerant"] != cmet.s1 or z["amountRefrigerant"] != cmet.s2 or z["timePeriod"] != cmet.s4]
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "REF",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)

@carbonroute.post('/carbonmeasurerefedit')
async def remove_ref(cmet: CarbonMeasureSEDEL):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)        

    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasurerefedit')
        return {"url": "/", "atype": False}

    if "carbonmeasure" in db_result:
        if cmet.metric == "REF":
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "REF"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "REF"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "REF"][0]

                if ([a for a in nmet["metrics"] if a["label"] == cmet.s11]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s11][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s12]
                    cmeas = []
                    cmeasNEW = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s12]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s12][0]
                        cmeas = myData["metrics"][0]["value"]
                        cmeasNEW = [z for z in cmeas if z["typeRefrigerant"] != cmet.s1 or z["amountRefrigerant"] != cmet.s2 or z["timePeriod"] != cmet.s4]
                    cmeasNEW.append({
                        "typeRefrigerant": cmet.s5,
                        "amountRefrigerant": cmet.s6,
                        "unitMeasure": cmet.s7,
                        "timePeriod": cmet.s8,
                        "carbonEmissions": cmet.s9,
                        "gwp": cmet.s10
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                    quarterData.append({
                        "label": cmet.s12,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s11,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "REF",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
                else:
                    yearData = []
                    quarterData = []
                    cmeas = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "typeRefrigerant": cmet.s5,
                        "amountRefrigerant": cmet.s6,
                        "unitMeasure": cmet.s7,
                        "timePeriod": cmet.s8,
                        "carbonEmissions": cmet.s9,
                        "gwp": cmet.s10
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s11]
                    quarterData.append({
                        "label": cmet.s12,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s11,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "REF",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)                    
            
"""
This is the endpoint used to purchase Carbon Credits from the Offsets feature
"""
@carbonroute.post('/buycarboncredits')
async def buy_carbon_credits(cmet: NewOffset):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /buycarboncredits')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:        
        if cmet.metric == "Credits":
            user = {
            "id": db_result["id"],
            "email": db_result["email"],
            "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Credits"]
            
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "Credits"]):
                nmet = [z for z in db_result["carbonmeasure"] if z["label"] == "Credits"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.year]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.year][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.quarter]
                    cmeasNEW = [{
                            "credits": cmet.credits
                    }]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.quarter]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.quarter][0]
                        cmeas = myData["metrics"][0]["value"]
                        carbonAdd = float(cmeas[0]["credits"]) + float(cmet.credits)
                        cmeasNEW = [{
                            "credits": carbonAdd
                        }]
                    
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.year]
                    quarterData.append({
                        "label": cmet.quarter,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.year,
                                "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                    }
                    newMet = {
                        "label": "Credits",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)

                else:
                    cmeas = [{
                        "credits": cmet.credits
                    }]
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.year]
                    tmeas.append({
                                "label": cmet.year,
                                "value": [
                                    {
                                        "label": cmet.quarter,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "Credits",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "carbonmeasure": mets
                    }
                    user.update(target)
                    callConnect.container7.upsert_item(body=user)
            else:
                user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "Credits"]
                newMet = {
                    "label": "Credits",
                    "metrics": [
                        {
                            "label": cmet.year,
                            "value": [
                                {
                                    "label": cmet.quarter,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "credits": cmet.credits
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)

"""
Endpoint used to update the target metrics.
"""
@carbonroute.post('/reduceemissionsadd')
async def add_reduce_emissions(cmet: ReduceEmissions):
    try:
        db_result = read_item(callConnect.container7, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /reduceemissionsadd')
        return {"url": "/", "atype": False}


    if "carbonmeasure" in db_result:
        if cmet.metric == "CFinish":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "carbonmeasure": []
            }
            mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CFinish"]
            if ([z for z in db_result["carbonmeasure"] if z["label"] == "CFinish"]):
                
                cmeas = [{
                    "carbonOffsets": cmet.m1,
                    "renewableEnergy": cmet.m2,
                    "employeeTravel": cmet.m3,
                    "vegetarianCatering": cmet.m4,
                    "dataCenters": cmet.m5,
                    "emissionReduction": cmet.m6,
                    "reduceEnergy": cmet.m7,
                    "other": cmet.m8,
                    "otherTxt": cmet.s1,
                    "vendors": cmet.s2,
                    "emissionsTarget": cmet.s3
                }]
                newMet = {
                    "label": "CFinish",
                    "metrics": [
                        {
                            "label": "1",
                            "value": cmeas
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)
            else:
                user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "carbonmeasure": []
                }
                mets = [z for z in db_result["carbonmeasure"] if z["label"] != "CFinish"]
                newMet = {
                    "label": "CFinish",
                    "metrics": [
                        {
                            "label": "1",
                            "value": [
                                {
                                    "carbonOffsets": cmet.m1,
                                    "renewableEnergy": cmet.m2,
                                    "employeeTravel": cmet.m3,
                                    "vegetarianCatering": cmet.m4,
                                    "dataCenters": cmet.m5,
                                    "emissionReduction": cmet.m6,
                                    "reduceEnergy": cmet.m7,
                                    "other": cmet.m8,
                                    "otherTxt": cmet.s1,
                                    "vendors": cmet.s2,
                                    "emissionsTarget": cmet.s3
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "carbonmeasure": mets
                }
                user.update(target)
                callConnect.container7.upsert_item(body=user)